module.exports = defineTest({
	description: 'uses the correct return value for async functions'
});
